==> SexyMap-v1.8.4.zip: SexyMap/localization/enUS.lua <==

local _, sm = ...
sm.L = {}
local L = sm.L

-- ./Borders.lua
L["1. Background"] = "1. Background"
L["2. Border"] = "2. Border"
L["3. Artwork"] = "3. Artwork"
L["4. Overlay"] = "4. Overlay"
L["5. Highlight"] = "5. Highlight"

L["Blend (normal)"] = "Blend (normal)"
L["Disable (opaque)"] = "Disable (opaque)"
L["Alpha Key (1-bit alpha)"] = "Alpha Key (1-bit alpha)"
L["Mod Blend (modulative)"] = "Mod Blend (modulative)"
L["Add Blend (additive)"] = "Add Blend (additive)"

L["Borders"] = "Borders"
L["Hide default border"] = "Hide default border"
L["Hide the default border on the minimap."] = "Hide the default border on the minimap."
L["Current Borders"] = "Current Borders"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "Enter a name to create a new border. The name can be anything you like to help you identify that border."
L["Create a new border"] = "Create a new border"
L["Clear & start over"] = "Clear & start over"
L["Clear the current borders and start fresh"] = "Clear the current borders and start fresh"
L["Background/edge"] = "Background/edge"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."
L["Enable"] = "Enable"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "Enable a backdrop and border for the minimap. This will let you set square borders more easily."
L["Scale"] = "Scale"
L["Opacity"] = "Opacity"
L["Background Texture"] = "Background Texture"
L["Texture"] = "Texture"
L["Open TexBrowser"] = "Open TexBrowser"
L["TexBrowser Not Installed"] = "TexBrowser Not Installed"
L["SharedMedia Texture"] = "SharedMedia Texture"
L["Tile Background"] = "Tile Background"
L["Tile Size"] = "Tile Size"
L["Backdrop Color"] = "Backdrop Color"
L["Backdrop Insets"] = "Backdrop Insets"
L["Border Texture"] = "Border Texture"
L["SharedMedia Border"] = "SharedMedia Border"
L["Border Color"] = "Border Color"
L["Border Edge Size"] = "Border Edge Size"
L["Preset"] = "Preset"
L["Save current settings as preset..."] = "Save current settings as preset..."
L["Select preset to load"] = "Select preset to load"
L["Select a preset to load settings from. This will erase any of your current borders."] = "Select a preset to load settings from. This will erase any of your current borders."
L["This will wipe out any current settings!"] = "This will wipe out any current settings!"
L["Delete"] = "Delete"
L["Really delete this preset? This can't be undone."] = "Really delete this preset? This can't be undone."
L["Entry Options"] = "Entry Options"
L["Name"] = "Name"
L["Really delete this border?"] = "Really delete this border?"
L["Texture Path"] = "Texture Path"
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."
L["Texture Options"] = "Texture Options"
L["Rotation Speed (seconds)"] = "Rotation Speed (seconds)"
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."
L["Static Rotation"] = "Static Rotation"
L["A static amount to rotate the texture by."] = "A static amount to rotate the texture by."
--L["Match player rotation"] = "Match player rotation"
--L["Normal rotation"] = "Normal rotation"
--L["Reverse rotation"] = "Reverse rotation"
--L["Do not match player rotation"] = "Do not match player rotation"
L["Texture Tint"] = "Texture Tint"
L["Horizontal Nudge"] = "Horizontal Nudge"
L["Vertical Nudge"] = "Vertical Nudge"
L["Layer"] = "Layer"
L["Blend Mode"] = "Blend Mode"
L["Disable Rotation"] = "Disable Rotation"
L["Force a square texture. Fixed distortion on square textures."] = "Force a square texture. Fixed distortion on square textures."

-- ./Buttons.lua
L["Calendar"] = "Calendar"
L["Tracking Button"] = "Tracking Button"
L["Zone Text"] = "Zone Text"
L["Zoom In Button"] = "Zoom In Button"
L["Zoom Out Button"] = "Zoom Out Button"
L["Map Button"] = "Map Button"
L["Clock"] = "Clock"

L["Guild Dungeon Difficulty Indicator (When Available)"] = "Guild Dungeon Difficulty Indicator (When Available)"
L["Challenge Mode Button (When Available)"] = "Challenge Mode Button (When Available)"
L["Dungeon Difficulty Indicator (When Available)"] = "Dungeon Difficulty Indicator (When Available)"
L["New Mail Indicator (When Available)"] = "New Mail Indicator (When Available)"
L["Video Recording Button (Mac OSX Only, When Available)"] = "Video Recording Button (Mac OSX Only, When Available)"
L["Voice Chat Button (When Available)"] = "Voice Chat Button (When Available)"
L["Queue Status Button (When Available)"] = "Queue Status Button (When Available)"

L["Addon Buttons"] = "Addon Buttons"
L["Dynamic Buttons"] = "Dynamic Buttons"
L["Standard Buttons"] = "Standard Buttons"
L["Lock Button Dragging"] = "Lock Button Dragging"
L["Let SexyMap handle button dragging"] = "Let SexyMap handle button dragging"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."
L["Let SexyMap control button visibility"] = "Let SexyMap control button visibility"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "Turn this off if you want another mod to handle which buttons are visible on the minimap."
L["Drag Radius"] = "Drag Radius"

L["Always"] = "Always"
L["Never"] = "Never"
L["On Hover"] = "On Hover"
L["Show %s:"] = "Show %s:"

L["Buttons"] = "Buttons"

-- ./Coordinates.lua
L["Coordinates"] = "Coordinates"
L["Enable Coordinates"] = "Enable Coordinates"
L["Lock Coordinates"] = "Lock Coordinates"
L["Font Size"] = "Font Size"
L["Font Color"] = "Font Color"
L["Reset Position"] = "Reset Position"

-- ./Fader.lua
L["Enable Minimap Fader"] = "Enable Minimap Fader"
L["Normal Opacity"] = "Normal Opacity"
L["Hover Opacity"] = "Hover Opacity"
L["Fader"] = "Fader"

-- ./General.lua
L["Lock Minimap"] = "Lock Minimap"
L["Clamp to screen"] = "Clamp to screen"
L["Prevent the minimap from being moved off the screen"] = "Prevent the minimap from being moved off the screen"
L["Right Click Configure"] = "Right Click Configure"
L["Right clicking the map will open the SexyMap options"] = "Right clicking the map will open the SexyMap options"
L["Auto Zoom-Out Delay"] = "Auto Zoom-Out Delay"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds)"] = "If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds)"

-- ./HudMap.lua
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."
L["Enable Hudmap"] = "Enable Hudmap"
L["Keybinding"] = "Keybinding"
L["HUD Color"] = "HUD Color"
L["Text Color"] = "Text Color"
L["GatherMate is a resource gathering helper mod. Installing it allows you to have resource pins on your HudMap."] = "GatherMate is a resource gathering helper mod. Installing it allows you to have resource pins on your HudMap."
L["Use GatherMate pins"] = "Use GatherMate pins"
L["Use QuestHelper pins"] = "Use QuestHelper pins"
L["Routes plots the shortest distance between resource nodes. Install it to show farming routes on your HudMap."] = "Routes plots the shortest distance between resource nodes. Install it to show farming routes on your HudMap."
L["Use Routes"] = "Use Routes"

-- ./Movers.lua
L["Movers Warning"] = "WARNING: This feature is not officially supported, expect problems when using this feature such as taints, loss of quest tracker functionality, or boss frames jumping around. Blizzard frames like the quest tracker and boss health aren't designed to be moved, I suggest you use addons that replace these frames e.g. Unit Frames for boss health."
L["Enable Movers"] = "Enable Movers"
L["Lock Movers"] = "Lock Movers"
L["Armored Man"] = "Armored Man"
L["Objectives Tracker"] = "Objectives Tracker"
L["Boss Frames"] = "Boss Frames"
L["Vehicle Seat"] = "Vehicle Seat"
L["Capture Bars"] = "Capture Bars"
L["Movers"] = "Movers"

-- ./Ping.lua
L["Show who pinged"] = "Show who pinged"
L["Show inside chat"] = "Show inside chat"
L["Show on minimap"] = "Show on minimap"
L["Ping"] = "Ping"

-- ./SexyMap.lua
L["Profiles"] = "Profiles"

-- ./Shapes.lua
L["Circle"] = "Circle"
L["Faded Circle (Small)"] = "Faded Circle (Small)"
L["Faded Circle (Large)"] = "Faded Circle (Large)"
L["Faded Square"] = "Faded Square"
L["Diamond"] = "Diamond"
L["Square"] = "Square"
L["Heart"] = "Heart"
L["Octagon"] = "Octagon"
L["Hexagon"] = "Hexagon"
L["Snowflake"] = "Snowflake"
L["Route 66"] = "Route 66"
L["Rounded - Bottom Right"] = "Rounded - Bottom Right"
L["Rounded - Bottom Left"] = "Rounded - Bottom Left"
L["Rounded - Top Right"] = "Rounded - Top Right"
L["Rounded - Top Left"] = "Rounded - Top Left"

L["Minimap shape"] = "Minimap shape"

-- ./ZoneText.lua
L["Text Width"] = "Text Width"
L["Font"] = "Font"
L["Horizontal Position"] = "Horizontal Position"
L["Vertical Position"] = "Vertical Position"
L["Background Color"] = "Background Color"

L["Zone Text"] = "Zone Text"

==> SexyMap-v7.3.3.zip: SexyMap/localization/enUS.lua <==

local _, sm = ...
sm.L = {}
local L = sm.L

-- ./Borders.lua
L["1. Background"] = "1. Background"
L["2. Border"] = "2. Border"
L["3. Artwork"] = "3. Artwork"
L["4. Overlay"] = "4. Overlay"
L["5. Highlight"] = "5. Highlight"

L["Blend (normal)"] = "Blend (normal)"
L["Disable (opaque)"] = "Disable (opaque)"
L["Alpha Key (1-bit alpha)"] = "Alpha Key (1-bit alpha)"
L["Mod Blend (modulative)"] = "Mod Blend (modulative)"
L["Add Blend (additive)"] = "Add Blend (additive)"

L["Borders"] = "Borders"
L["Hide default border"] = "Hide default border"
L["Hide the default border on the minimap."] = "Hide the default border on the minimap."
L["Current Borders"] = "Current Borders"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "Enter a name to create a new border. The name can be anything you like to help you identify that border."
L["Create a new border"] = "Create a new border"
L["Clear & start over"] = "Clear & start over"
L["Clear the current borders and start fresh"] = "Clear the current borders and start fresh"
L["Background/edge"] = "Background/edge"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."
L["Enable"] = "Enable"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "Enable a backdrop and border for the minimap. This will let you set square borders more easily."
L["Scale"] = "Scale"
L["Opacity"] = "Opacity"
L["Background Texture"] = "Background Texture"
L["Texture"] = "Texture"
L["Open TexBrowser"] = "Open TexBrowser"
L["TexBrowser Not Installed"] = "TexBrowser Not Installed"
L["SharedMedia Texture"] = "SharedMedia Texture"
L["Tile Background"] = "Tile Background"
L["Tile Size"] = "Tile Size"
L["Backdrop Color"] = "Backdrop Color"
L["Backdrop Insets"] = "Backdrop Insets"
L["Border Texture"] = "Border Texture"
L["SharedMedia Border"] = "SharedMedia Border"
L["Border Color"] = "Border Color"
L["Border Edge Size"] = "Border Edge Size"
L["Preset"] = "Preset"
L["Save current settings as preset..."] = "Save current settings as preset..."
L["Select preset to load"] = "Select preset to load"
L["Select a preset to load settings from. This will erase any of your current borders."] = "Select a preset to load settings from. This will erase any of your current borders."
L["This will wipe out any current settings!"] = "This will wipe out any current settings!"
L["Delete"] = "Delete"
L["Really delete this preset? This can't be undone."] = "Really delete this preset? This can't be undone."
L["Entry Options"] = "Entry Options"
L["Name"] = "Name"
L["Really delete this border?"] = "Really delete this border?"
L["Texture Path"] = "Texture Path"
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."
L["Texture Options"] = "Texture Options"
L["Rotation Speed (seconds)"] = "Rotation Speed (seconds)"
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."
L["Static Rotation"] = "Static Rotation"
L["A static amount to rotate the texture by."] = "A static amount to rotate the texture by."
--L["Match player rotation"] = "Match player rotation"
--L["Normal rotation"] = "Normal rotation"
--L["Reverse rotation"] = "Reverse rotation"
--L["Do not match player rotation"] = "Do not match player rotation"
L["Texture Tint"] = "Texture Tint"
L["Horizontal Nudge"] = "Horizontal Nudge"
L["Vertical Nudge"] = "Vertical Nudge"
L["Layer"] = "Layer"
L["Blend Mode"] = "Blend Mode"
L["Disable Rotation"] = "Disable Rotation"
L["Force a square texture. Fixed distortion on square textures."] = "Force a square texture. Fixed distortion on square textures."
L["Width"] = "Width"
L["Height"] = "Height"

L["Default Presets"] = "Default Presets"
L["User-Submitted Presets"] = "User-Submitted Presets"

-- ./Buttons.lua
L["Calendar"] = "Calendar"
L["Tracking Button"] = "Tracking Button"
L["Zone Text"] = "Zone Text"
L["Zoom In Button"] = "Zoom In Button"
L["Zoom Out Button"] = "Zoom Out Button"
L["Map Button"] = "Map Button"
L["Clock"] = "Clock"

L["Guild Dungeon Difficulty Indicator (When Available)"] = "Guild Dungeon Difficulty Indicator (When Available)"
L["Challenge Mode Button (When Available)"] = "Challenge Mode Button (When Available)"
L["Dungeon Difficulty Indicator (When Available)"] = "Dungeon Difficulty Indicator (When Available)"
L["New Mail Indicator (When Available)"] = "New Mail Indicator (When Available)"
L["Voice Chat Button (When Available)"] = "Voice Chat Button (When Available)"
L["Queue Status (PvP/LFG) Button (When Available)"] = "Queue Status (PvP/LFG) Button (When Available)"
L["Garrison Button (When Available)"] = "Garrison Button (When Available)"

L["Addon Buttons"] = "Addon Buttons"
L["Dynamic Buttons"] = "Dynamic Buttons"
L["Standard Buttons"] = "Standard Buttons"
L["Lock Button Dragging"] = "Lock Button Dragging"
L["Let SexyMap handle button dragging"] = "Let SexyMap handle button dragging"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."
L["Let SexyMap control button visibility"] = "Let SexyMap control button visibility"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "Turn this off if you want another mod to handle which buttons are visible on the minimap."
L["Drag Radius"] = "Drag Radius"
L["Visibility"] = "Visibility"

L["Always"] = "Always"
L["Never"] = "Never"
L["On Hover"] = "On Hover"
L["Show %s:"] = "Show %s:"

L["Buttons"] = "Buttons"

-- ./Coordinates.lua
L["Coordinates"] = "Coordinates"
L["Enable Coordinates"] = "Enable Coordinates"
L["Lock Coordinates"] = "Lock Coordinates"
L["Font Size"] = "Font Size"
L["Font Color"] = "Font Color"
L["Reset Position"] = "Reset Position"
L.updateRate = "Update Rate (seconds)"
L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."

-- ./Fader.lua
L["Enable Minimap Fader"] = "Enable Minimap Fader"
L["Normal Opacity"] = "Normal Opacity"
L["Hover Opacity"] = "Hover Opacity"
L["Fader"] = "Fader"

-- ./HudMap.lua
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."
L["Enable Hudmap"] = "Enable Hudmap"
L["Keybinding"] = "Keybinding"
L["HUD Color"] = "HUD Color"
L["Text Color"] = "Text Color"
L["Toggle HudMap On/Off"] = "Toggle HudMap On/Off"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."

-- ./Movers.lua
L["Movers Warning"] = "WARNING: This feature is not officially supported, expect problems when using this feature such as taints, loss of quest tracker functionality, or boss frames jumping around. Blizzard frames like the quest tracker and boss health aren't designed to be moved, I suggest you use addons that replace these frames e.g. Unit Frames for boss health."
L["Enable Movers"] = "Enable Movers"
L["Lock Movers"] = "Lock Movers"
L["Armored Man"] = "Armored Man"
L["Objectives Tracker"] = "Objectives Tracker"
L["Boss Frames"] = "Boss Frames"
L["Vehicle Seat"] = "Vehicle Seat"
L["Capture Bars"] = "Capture Bars"
L["Movers"] = "Movers"
L["Disabling the movers will make them reset next time you relog, are you sure?"] = "Disabling the movers will make them reset next time you relog, are you sure?"

-- ./Ping.lua
L["Show who pinged"] = "Show who pinged"
L["Show inside chat"] = "Show inside chat"
L["Show on minimap"] = "Show on minimap"
L["Ping"] = "Ping"

-- ./SexyMap.lua
L["Lock Minimap"] = "Lock Minimap"
L["Clamp to screen"] = "Clamp to screen"
L["Prevent the minimap from being moved off the screen"] = "Prevent the minimap from being moved off the screen"
L["Right Click Configure"] = "Right Click Configure"
L["Right clicking the map will open the SexyMap options"] = "Right clicking the map will open the SexyMap options"
L["Auto Zoom-Out Delay"] = "Auto Zoom-Out Delay"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."
L["Show North Tag"] = "Show North Tag"
L["Profiles"] = "Profiles"
L["Copy a Profile"] = "Copy a Profile"
L["Copying this profile will reload your UI, are you sure?"] = "Copying this profile will reload your UI, are you sure?"
L["Delete a Profile"] = "Delete a Profile"
L["Really delete this profile?"] = "Really delete this profile?"
L["Reset Current Profile"] = "Reset Current Profile"
L["Resetting this profile will reload your UI, are you sure?"] = "Resetting this profile will reload your UI, are you sure?"
L["Quickly change the look of your minimap by using a minimap preset."] = "Quickly change the look of your minimap by using a minimap preset."
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."
L["Use Global Profile"] = "Use Global Profile"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."
L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "Are you sure you want to switch back to using a character specific profile? This will reload your UI."

-- ./Shapes.lua
L["Circle"] = "Circle"
L["Faded Circle (Small)"] = "Faded Circle (Small)"
L["Faded Circle (Large)"] = "Faded Circle (Large)"
L["Faded Square"] = "Faded Square"
L["Diamond"] = "Diamond"
L["Square"] = "Square"
L["Heart"] = "Heart"
L["Octagon"] = "Octagon"
L["Hexagon"] = "Hexagon"
L["Snowflake"] = "Snowflake"
L["Route 66"] = "Route 66"
L["Rounded - Bottom Right"] = "Rounded - Bottom Right"
L["Rounded - Bottom Left"] = "Rounded - Bottom Left"
L["Rounded - Top Right"] = "Rounded - Top Right"
L["Rounded - Top Left"] = "Rounded - Top Left"

L["Minimap shape"] = "Minimap shape"

-- ./ZoneText.lua
L["Text Width"] = "Text Width"
L["Font"] = "Font"
L["Horizontal Position"] = "Horizontal Position"
L["Vertical Position"] = "Vertical Position"
L["Background Color"] = "Background Color"
L["(Requires button visibility control in the Buttons menu)"] = "(Requires button visibility control in the Buttons menu)"

L["Zone Text"] = "Zone Text"
